@@ -203,6 +203,8 @@ function named_generate(){
 	global $conf_dtc_system_username;
 	global $conf_dtc_system_groupname;
 	global $conf_autogen_default_subdomains;
+	global $conf_default_zones_ttl;
+
 	$slave_file = "";
 	$todays_serial = date("YmdH");
 
@@ -216,6 +218,7 @@ function named_generate(){
 	if($num_rows < 1){//		die("No account to generate");
 	}
 	for($i=0;$i<$num_rows;$i++){
+		unset($wildcard_dns_txt);
 		$row = mysql_fetch_array($result) or die ("Cannot fetch user");
 		$web_name = $row["name"];
 		// for empty web_names, we need to skip
@@ -228,7 +231,7 @@ function named_generate(){
 		$web_serial_flag = $row["generate_flag"];
 		$ip_addr = $row["ip_addr"];
 		// domain wide TTL
-		$domain_ttl = 7200;
+		$domain_ttl = $conf_default_zones_ttl;
 		if (isset($row["ttl"]))
 		{
 			$domain_ttl = $row["ttl"];	
@@ -309,7 +312,8 @@ function named_generate(){
 		$web_extention = substr($web_name,-strpos(strrev($web_name),'.'));
 
 		$web_default_subdomain = $row["default_subdomain"];
-		
+		$wildcard_dns = $row["wildcard_dns"];
+
 		// Get the owner informations
 		$query2 = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$web_owner';";
 		$result2 = mysql_query ($query2)or die("Cannot execute query \"$query2\"");
@@ -418,11 +422,10 @@ $more_mx_server
 				$subdomain = mysql_fetch_array($result2) or die ("Cannot fetch user");
 				$web_subname = $subdomain["subdomain_name"];
 				// TTL support
-				$sub_ttl = 7200;
-                                if (isset($subdomain["ttl"]))
-                                {
-                                        $sub_ttl = $subdomain["ttl"];
-                                }
+				$sub_ttl = $conf_default_zones_ttl;
+				if (isset($subdomain["ttl"])){
+					$sub_ttl = $subdomain["ttl"];
+				}
 				// Check if it's an IP or not, to know if it's a CNAME record or a A record
 				if(isIP($subdomain["ip"]) || $subdomain["ip"] == "default"){
 					if($subdomain["ssl_ip"] != "none"){
@@ -471,15 +474,16 @@ $more_mx_server
 					$is_list_subdomain_set = "yes";
 				}
 				// if we have a srv_record here (ie a port, then we don't write the normal subdomain entry, just the SRV record
-			 	if (isset($subdomain["srv_record"]) && $subdomain["srv_record"] != "")
-				{
+			 	if (isset($subdomain["srv_record"]) && $subdomain["srv_record"] != ""){
 					$this_site_file .= "$web_subname	$sub_ttl	SRV	0	10	".$subdomain["srv_record"]."	".$subdomain["ip"]."\n";
 				} else {	
 					// write TTL values into subdomain
 					if ($conf_use_cname_for_subdomains == "yes"){
 						$this_site_file .= "$web_subname	$sub_ttl	IN	CNAME	@\n";
-
 					}else{
+						if($web_subname == $web_default_subdomain && $wildcard_dns == "yes"){
+							$wildcard_dns_txt = "*        $sub_ttl        IN      $the_ip_writed\n";
+						}
 						$this_site_file .= "$web_subname	$sub_ttl	IN	$the_ip_writed\n";
 					}
 				}
@@ -524,6 +528,9 @@ $more_mx_server
                         	        $this_site_file .= "list        IN      CNAME	@\n";
 				}
 			}
+			if(isset($wildcard_dns_txt)){
+				$this_site_file .= $wildcard_dns_txt;
+			}
 			if($web_serial_flag=="yes"){
 				$console .= "Updating zone file for domain $web_name using serial : $todays_serial, ipaddr : $ip_to_write<br>";
 				$filep = fopen("$conf_generated_file_path/$conf_named_zonefiles_path/$web_name", "w+");
