@@ -91,6 +91,7 @@ function sendVPSReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
 	global $pro_mysql_client_table;
 	global $pro_mysql_vps_table;
 	global $conf_webmaster_email_addr;
+	global $conf_vps_renewal_lastwarning;
 
 	global $conf_message_subject_header;
 	global $dtcshared_path;
@@ -118,6 +119,11 @@ function sendVPSReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
 	for($i=0;$i<$n;$i++){
 		$vps = mysql_fetch_array($r);
 
+		// Shutdown the VPS if it reaches the shutdown warning
+		if($remaining_days == -$conf_vps_renewal_lastwarning){
+			remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"shutdown_vps");
+		}
+
 		// Get the admin
 		$q2 = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$vps["owner"]."';";
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -166,7 +172,7 @@ for($i=0;$i<$n;$i++){
 	sendVPSReminderEmail($before[$i],"vps_will_expire.txt");
 }
 // Send reminders the day of the expiration
-sendVPSReminderEmail(0,"vps_expired_today.txt","yes");
+sendVPSReminderEmail(0,"vps_expired_today.txt","no");
 // Send reminders after expiration
 $after = explode("|",$conf_vps_renewal_after);
 $n = sizeof($after);
@@ -257,7 +263,7 @@ for($i=0;$i<$n;$i++){
 	sendDedicatedReminderEmail($before[$i],"server_will_expire.txt");
 }
 // Send reminders the day of the expiration
-sendDedicatedReminderEmail(0,"server_expired_today.txt","yes");
+sendDedicatedReminderEmail(0,"server_expired_today.txt","no");
 // Send reminders after expiration
 $after = explode("|",$conf_vps_renewal_after);
 $n = sizeof($after);
@@ -339,7 +345,7 @@ for($i=0;$i<$n;$i++){
 	sendSharedHostingReminderEmail($before[$i],"shared_will_expire.txt");
 }
 // Send reminder the day of expiration
-sendSharedHostingReminderEmail(0,"shared_expired_today.txt","yes");
+sendSharedHostingReminderEmail(0,"shared_expired_today.txt","no");
 // Send reminders after expiration
 $after = explode("|",$conf_shared_renewal_after);
 $n = sizeof($after);
@@ -352,4 +358,4 @@ sendSharedHostingReminderEmail(-$conf_shared_renewal_lastwarning,"shared_expired
 // Send rexpiration reminder
 sendSharedHostingReminderEmail(-$conf_shared_renewal_shutdown,"shared_expired_shutdown.txt","yes");
 
-?>
\ No newline at end of file
+?>
