@@ -272,6 +272,10 @@ if($n != 1){
 }
 $config_vals = mysql_fetch_array($r);
 
+# Sets old install of ssh shell path to be /usr/bin/dtc-chroot-shell and not /bin/dtc-chroot-shell
+$q = "UPDATE ssh_access SET shell='/usr/bin/dtc-chroot-shell' WHERE shell='/bin/dtc-chroot-shell';";
+$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+
 // Iterate on all mailing lists to set the correct recipient delimiter
 echo "-> Changing all recipient delimiter for mailing lists: ";
 $q = "SELECT * FROM mailinglist";
@@ -418,4 +422,4 @@ if (!$r)
 }
 echo "done!\n";
 
-?>
\ No newline at end of file
+?>
