@@ -18,5 +18,10 @@ CREATE TABLE IF NOT EXISTS secpayconf (
   use_maxmind enum('yes','no') NOT NULL default 'no',
   maxmind_login varchar(255) NOT NULL default '',
   maxmind_license_key varchar(255) NOT NULL default '',
+
+  use_webmoney enum('yes','no') NOT NULL default 'no',
+  webmoney_license_key varchar(255) NOT NULL default '',
+  webmoney_wmz varchar(255) NOT NULL default '',
+
   UNIQUE KEY unicrow (unicrow)
 ) TYPE=MyISAM
