@@ -14,6 +14,10 @@ CREATE TABLE IF NOT EXISTS subdomain (
   associated_txt_record varchar(128) NOT NULL default '',
   generate_vhost enum('yes','no') NOT NULL default 'yes',
   ssl_ip varchar(16) NOT NULL default 'none',
+  nameserver_for varchar(64) default NULL,
+  srv_record varchar(64) default NULL,
+  add_default_charset varchar(32) NOT NULL default 'dtc-wont-add',
+  customize_vhost text NOT NULL,
   PRIMARY KEY  (id),
   UNIQUE KEY unic_subdomain (domain_name,subdomain_name)
 ) TYPE=MyISAM
