@@ -242,6 +242,7 @@ function fetchAdminStats($admin){
 		{
 			$ret["err"] = 5;
 			$ret["mesg"] = "Cannot query \"$qu\" !".mysql_error()." line ".__LINE__." file ".__FILE__;
+			mysql_select_db($conf_mysql_db);
 			return $ret;
 		}
 		$nbr_mysql_user = mysql_num_rows($ru);
@@ -255,6 +256,7 @@ function fetchAdminStats($admin){
 			{
 				$ret["err"] = 6;
 				$ret["mesg"] = "Cannot query \"$q\" !".mysql_error()." line ".__LINE__." file ".__FILE__;
+				mysql_select_db($conf_mysql_db);
 				return $ret;
 			}
 			$db_nbr = mysql_num_rows($r);
@@ -267,6 +269,7 @@ function fetchAdminStats($admin){
 				{
 					$ret["err"] = 7;
 					$ret["mesg"] = "Cannot query \"$q\" !".mysql_error();
+					mysql_select_db($conf_mysql_db);
 					return $ret;
 				}
 				$num_tbl = mysql_num_rows($result);
@@ -553,6 +556,7 @@ function fetchAdminData($adm_login,$adm_input_pass){
 		$domain["txt_root_entry2"] = $row["txt_root_entry2"];
 		$domain["catchall_email"] = $row["catchall_email"];
 		$domain["domain_parking"] = $row["domain_parking"];
+		$domain["wildcard_dns"] = $row["wildcard_dns"];
 
 		$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$name' ORDER BY subdomain_name;";
 		$result2 = mysql_query ($query2);
