@@ -27,6 +27,9 @@ function drawAdminTools_PackageInstaller($domain,$adm_path){
 	$txt = "";
 	$dir = $dtcshared_path."/package-installer";
 
+	if(isset($_REQUEST["pkg"]) && !preg_match("/^([_a-z0-9]+)([_.a-z0-9-]*)([_.a-z0-9]+)\$/",$_REQUEST["pkg"])){
+		die("Requested package name is invalid");
+	}
 
 	if(isset($_REQUEST["action"]) && ($_REQUEST["action"] == "do_install" || $_REQUEST["action"] == "prepareinstall")){
 		$pkg_path = $dir."/".$_REQUEST["pkg"];
@@ -45,7 +48,9 @@ function drawAdminTools_PackageInstaller($domain,$adm_path){
 		}
 		// Check if user has enough rights
 		checkLoginPassAndDomain($adm_login,$adm_pass,$edit_domain);
-		checkSubdomainFormat($_REQUEST["subdomain"]);
+		if( !checkSubdomainFormat($_REQUEST["subdomain"])){
+			die( _("Target subdomain is wrong."));
+		}
 		$admin_path = getAdminPath($adm_login);
 		$target = "$admin_path/$edit_domain/subdomains/".$_REQUEST["subdomain"]."/html";
 		if(!is_dir($target)){
@@ -80,6 +85,9 @@ function drawAdminTools_PackageInstaller($domain,$adm_path){
 				exec($cmd,$exec_out,$return_val);
 				$realtarget = "$target";
 			}else{
+				if( checkSubdomainFormat($_REQUEST["dtcpkg_directory"]) == false && $_REQUEST["dtcpkg_directory"] != ""){
+					die(_("Target directory is wrong."));
+				}
 				$cmd = "mv $target/".$pkg_info["renamedir_to"]." $target/".$_REQUEST["dtcpkg_directory"];
 				$x .= "=> Moving ".$pkg_info["renamedir_to"]." to ".$_REQUEST["dtcpkg_directory"]."<br>";
 				exec($cmd,$exec_out,$return_val);
