@@ -4,6 +4,9 @@ require("$dtcshared_path/securepay/paiement_config.php");
 if($conf_use_worldpay == "yes")	include("$dtcshared_path/securepay/gateways/worldpay.php");
 include("$dtcshared_path/securepay/gateways/paypal.php");
 include("$dtcshared_path/securepay/gateways/enets.php");
+// -- zion --
+include("$dtcshared_path/securepay/gateways/webmoney.php");
+// -- zion --
 require("$dtcshared_path/securepay/pay_functions.php");
 
 function get_secpay_conf(){
