@@ -51,6 +51,12 @@ if(isset($adm_email_pass) && !ereg("^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)([a-zA-Z0-9]
 }
 
 if(isset($addrlink) && $addrlink != ""){
+        $check = str_replace(":","",$addrlink);
+        $check = str_replace("/","",$check);
+        if(!preg_match("/^([a-z0-9]+)([.a-z0-9-]+)([a-z0-9])\$/",$check)){
+                die("Parameter incorect in addrlink.");
+        }
+
 	$vps_exploded = explode(":",$addrlink);
 	if(sizeof($vps_exploded) > 1){
 		$server_subscreen = $vps_exploded[0];
