@@ -39,8 +39,14 @@ $pro_mysql_tik_admins_table = "tik_admins";
 $pro_mysql_tik_queries_table = "tik_queries";
 $pro_mysql_tik_cats_table = "tik_cats";
 $pro_mysql_ssl_ips_table = "ssl_ips";
+$pro_mysql_dedicated_ips_table = "dedicated_ip";
 $pro_mysql_dedicated_table = "dedicated";
 $pro_mysql_companies_table = "companies";
 $pro_mysql_invoicing_table = "invoicing";
 $pro_mysql_completedorders_table = "completedorders";
+$pro_mysql_spent_moneyout_table = "spent_moneyout";
+$pro_mysql_spent_providers_table = "spent_providers";
+$pro_mysql_spent_type_table = "spent_type";
+$pro_mysql_spent_bank_table = "spent_bank";
+$pro_mysql_ip_pool_table = "ip_pool";
 ?>
